@@ -79,8 +79,10 @@ class Client(metaclass=_Singleton):
 
     Parameters
     ----------
-    bot : :class:`discord.Client`
+    bot : :class:`BotT`
         The bot instance.
+    cog: :class:`CogT`
+        The cog to register the client to.
     player: Optional[:class:`Player`]
         The class that should be used for the player. Defaults to ``Player``.
         Do not change this unless you know what you are doing!
@@ -95,6 +97,8 @@ class Client(metaclass=_Singleton):
         the player was moved via the fail-over mechanism, the player will still move back to the original
         node when it becomes available. This behaviour can be avoided in custom player implementations by
         setting `self._original_node` to `None` in the `change_node` function.
+    config_folder: Optional[:class:`pathlib.Path`]
+        The path to the config folder. Defaults to ``CONFIG_DIR``.
     """
 
     _local_node_manager: LocalNodeManager
@@ -835,9 +839,7 @@ class Client(metaclass=_Singleton):
             asyncstdlib.filter(operator.attrgetter("available"), self.node_manager.managed_nodes)
         )
 
-        if not available_nodes:
-            return None
-        return random.choice(available_nodes)
+        return random.choice(available_nodes) if available_nodes else None
 
     async def _get_tracks(
         self,
@@ -1088,13 +1090,14 @@ class Client(metaclass=_Singleton):
         *,
         additional_role_ids: list = None,
         additional_user_ids: list = None,
+        bot: BotT = None,
     ) -> bool:
         if additional_user_ids and user.id in additional_user_ids:
             return True
         if additional_role_ids and await asyncstdlib.any(r.id in additional_role_ids for r in user.roles):
             return True
         return await self.player_config_manager.is_dj(
-            user=user, guild=guild, additional_role_ids=None, additional_user_ids=None
+            user=user, guild=guild, additional_role_ids=None, additional_user_ids=None, bot=bot
         )
 
     async def generate_mix_playlist(
