@@ -499,6 +499,9 @@ class Player(VoiceProtocol):
                 self,
             )
             return
+        if self.current:
+            LOGGER.trace("Auto Empty Queue task for %s - Current track is not empty - discarding", self)
+            return
         if (
             self.queue.empty()
             and (
@@ -633,6 +636,16 @@ class Player(VoiceProtocol):
             await self._dispatch_voice_update()
 
     async def on_voice_state_update(self, data: dict) -> None:
+        """|coro|
+
+        An abstract method that is called when the client's voice state
+        has changed. This corresponds to ``VOICE_STATE_UPDATE``.
+
+        Parameters
+        ------------
+        data: :class:`dict`
+            The raw :ddocs:`voice state payload <resources/voice#voice-state-object>`.
+        """
         self._voice_state.update({"sessionId": data["session_id"]})
         self.channel_id = data["channel_id"]
         if not self.channel_id:  # We're disconnecting
@@ -666,6 +679,7 @@ class Player(VoiceProtocol):
     ) -> None:
         """
         Adds a track to the queue.
+
         Parameters
         ----------
         requester: :class:`int`
@@ -678,6 +692,10 @@ class Player(VoiceProtocol):
             If index is left unspecified, the default behaviour is to append the track. Defaults to `None`.
         query: Optional[:class:`Query`]
             The query that was used to search for the track.
+
+        Returns
+        -------
+        :class:`None`
         """
 
         at = await self._query_to_track(requester, track, query)
@@ -800,8 +818,8 @@ class Player(VoiceProtocol):
         bypass_cache: bool = False,
         node: Node = None,
     ) -> None:
-        """
-        Plays the given track.
+        """Plays the given track.
+
         Parameters
         ----------
         track: Optional[Union[:class:`Track`, :class:`dict`]]
@@ -1097,12 +1115,12 @@ class Player(VoiceProtocol):
         if event.node.identifier != self.node.identifier:
             return
         if isinstance(event, TrackStuckEvent) or isinstance(event, TrackEndEvent) and event.reason == "FINISHED":
+            self.last_track = self.current
             await self.next()
-            self.last_track = event.track
             self.next_track = None if self.queue.empty() else self.queue.raw_queue.popleft()
         elif isinstance(event, TrackExceptionEvent):
+            self.last_track = self.current
             await self.next()
-            self.last_track = event.track
             self.next_track = None if self.queue.empty() else self.queue.raw_queue.popleft()
 
     async def _update_state(self, state: dict) -> None:
@@ -1218,6 +1236,7 @@ class Player(VoiceProtocol):
             self.last_track = None
             self.next_track = None
             self.stopped = True
+            self.current = None
             with contextlib.suppress(ValueError):
                 await self.player_manager.remove(self.channel.guild.id)
             await self.node.send(op="destroy", guildId=self.guild_id)
@@ -1906,9 +1925,9 @@ class Player(VoiceProtocol):
             "paused": self.paused,
             "repeat_queue": self.config.repeat_queue,
             "repeat_current": self.config.repeat_current,
-            "shuffle": await self.player_manager.client.player_config_manager.get_shuffle(self.guild.id),
-            "auto_shuffle": await self.player_manager.client.player_config_manager.get_auto_shuffle(self.guild.id),
-            "auto_play": await self.player_manager.client.player_config_manager.get_auto_play(self.guild.id),
+            "shuffle": self.config.shuffle,
+            "auto_shuffle": self.config.auto_shuffle,
+            "auto_play": self.config.auto_play,
             "auto_play_playlist_id": self._autoplay_playlist.id if self._autoplay_playlist is not None else None,
             "volume": self.volume,
             "position": self.position,
